@@ -14,8 +14,19 @@ $(document).ready(function () {
 			// ckeditor default settings, will be overwritten by CKEDITOR_SETTINGS
 			'language': 'en',
 			'skin': 'moono',
-			'toolbar': 'CMS',
 			'toolbar_CMS': [
+				['Undo', 'Redo'],
+				['cmsplugins', '-', 'ShowBlocks'],
+				['Format', 'Styles'],
+				['TextColor', 'BGColor', '-', 'PasteText', 'PasteFromWord'],
+				['Maximize', ''],
+				'/',
+				['Bold', 'Italic', 'Underline', '-', 'Subscript', 'Superscript', '-', 'RemoveFormat'],
+				['JustifyLeft', 'JustifyCenter', 'JustifyRight'],
+				['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 'Table'],
+				['Source']
+			],
+			'toolbar_HTMLField': [
 				['Undo', 'Redo'],
 				['cmsplugins', '-', 'ShowBlocks'],
 				['Format', 'Styles'],
@@ -28,6 +39,7 @@ $(document).ready(function () {
 				['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 'Table'],
 				['Source']
 			],
+
 			'allowedContent': true,
 			'toolbarCanCollapse': false,
 			'extraPlugins': 'cmsplugins'
@@ -37,6 +49,7 @@ $(document).ready(function () {
 			this.container = $('#' + container);
 
 			// add additional settings to options
+			this.options.toolbar = settings.toolbar;
 			this.options = $.extend(true, {
 				'settings': settings
 			}, this.options, options);
